envaddr

package module
v0.0.0-...-f2bfd27 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 24, 2022 License: Unlicense Imports: 2 Imported by: 12

README

envaddr

Get Listen Address From env

go get -u github.com/lemon-mint/envaddr
func Get(defaultAddr string) string

This function attempts to get the address from the environment variables PORT, HOST and IP.

If none of these are set, it returns the default address.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(defaultAddr string) string

Types

This section is empty.

Jump to